using System;
using System.Drawing;
using System.IO;
using System.Windows.Forms;
using GrapeCity.ActiveAnalysis.Layout;
using Color=GrapeCity.ActiveAnalysis.Drawing.Color;
using Font=GrapeCity.ActiveAnalysis.Drawing.Font;
using System.Text;

namespace GrapeCity.ActiveAnalysis.Samples
{
	/// <summary>
	/// This sample demonstrates possible API actions under PivotView.
	/// </summary>
	public partial class MainForm : Form
	{
		/// <summary>
		/// Ctor.
		/// </summary>
		public MainForm()
		{
			InitializeComponent();

			_createFilterBtn.Click += OnCreateFilter;
			_showTrendLineBtn.Click += OnShowTrendLine;
			_showChartBtn.Click += OnShowChart;
			
			Connect();
		}

		#region Connection to data source

		/// <summary>
		/// This function performs connection to local cube data source.
		/// </summary>
		private void Connect()
		{
			_localCubeDataSource.LocalCubeFile = Application.StartupPath + @"..//GrapeCity\ActiveAnalysis\DataSources\NWind\NwindLocalCube.ddacube";
			_localCubeDataSource.Connect();

			_pivotView.DataSource = _localCubeDataSource;

            _pivotView.Read(new FileInfo(Application.StartupPath + @"..//GrapeCity\ActiveAnalysis\Layouts\NWind\Top 3 Ordered Products per Country.analysis"), PersistSettings.Layout);
		}

		#endregion

		#region Layout actions

		private void OnCreateFilter(object sender, EventArgs e)
		{
			// Create new layout
			using (ILayoutActions la = _pivotView.BeginLayoutUpdate("Create Filter"))
			{
				// Clear old layout
				la.ClearLayout();
                
				la.SetCellFormat(new Font(SystemFonts.DefaultFont.FontFamily.Name, 12), Color.Empty, Color.Empty, TextOrientation.Auto);
				
				la.SetMarkingType(MarkingType.Text);
				la.InsertField("[Measures].[Total Product Cost]", ShelfKind.LabelShelf, 0);
				la.InsertField("[Order Date].[Order Date]", ShelfKind.RowShelf, 0);
				la.DrillHierarchy("[Order Date].[Order Date]", 2, ShelfKind.RowShelf);
				la.SetFilter("[Measures].[Total Product Cost]", 1000, 2000);

				// It is necessary to commit this action!!!
				la.Commit();
			}
		}

		private void OnShowTrendLine(object sender, EventArgs e)
		{
			// Create new layout
			using (ILayoutActions la = _pivotView.BeginLayoutUpdate("Show Trend Line"))
			{
				// Clear old layout
				la.ClearLayout();

				la.SetMarkingType(MarkingType.Circle);
				la.InsertField("[Measures].[Total Product Cost]", ShelfKind.ColumnShelf, 0);
				la.InsertField("[Measures].[Freight]", ShelfKind.RowShelf, 0);
				la.InsertField("[Order Date].[Order Date]", ShelfKind.ColorShelf, 0);
				la.DrillHierarchy("[Order Date].[Order Date]", 2, ShelfKind.ColorShelf);
				la.InsertField("[Measures].[Discount]", ShelfKind.SizeShelf, 0);
				la.DrawTrend(true);
				la.SetPolynomialTrend(6, TrendOptions.AllowTrendPerColor | TrendOptions.TrendPerColumn | TrendOptions.TrendPerRow);

				// It is necessary to commit this action!!!
				la.Commit();
			}
		}

		private void OnShowChart(object sender, EventArgs e)
		{
			// Create new layout
			using (ILayoutActions la = _pivotView.BeginLayoutUpdate("Show Chart"))
			{
				// Clear old layout
				la.ClearLayout();

				la.SetMarkingType(MarkingType.Line);
				la.InsertField("[Measures].[Total Product Cost]", ShelfKind.ColumnShelf, 0);
				la.InsertField("[Order Date].[Order Date]", ShelfKind.RowShelf, 0);
				la.DrillHierarchy("[Order Date].[Order Date]", 2, ShelfKind.RowShelf);
				la.InsertField("[Measures].[Discount]", ShelfKind.ColorShelf, 0);
				la.InsertField("[Measures].[Freight]", ShelfKind.SizeShelf, 0);
				
				// It is necessary to commit this action!!!
				la.Commit();
			}
		}

		#endregion

		#region Helpers

		[System.Runtime.InteropServices.DllImport("Shfolder.dll")]
		private static extern int SHGetFolderPath(IntPtr hwndOwner, int nFolder, IntPtr hToken, int dwFlags, StringBuilder lpszPath);
		private static string MyDocumentsPath
		{
			get
			{
				StringBuilder comDoc = new StringBuilder(260);
				SHGetFolderPath(IntPtr.Zero, 0x002e, IntPtr.Zero, 0, comDoc);
				return comDoc.ToString();
			}
		}

		#endregion

        private void button1_Click(object sender, EventArgs e)
        {

           
                System.Reflection.PropertyInfo[] props = _pivotView.GetLayoutState().Filters[0].GetType().GetProperties();
                double value = (double)props[1].GetValue(_pivotView.GetLayoutState().Filters[0], null);
                string Expression = props[2].GetValue(_pivotView.GetLayoutState().Filters[0], null).ToString();
                string UniqueFieldName = props[3].GetValue(_pivotView.GetLayoutState().Filters[0], null).ToString();

                MessageBox.Show("Value: " + value.ToString() + Environment.NewLine + "Expression:" + Expression + Environment.NewLine + "Unique Field Name:" + UniqueFieldName);
            
        
          
        
        }
	}
}
